<?php
/**
 * Output properly formatted numeric value
 *
 */
function spray_pay_formatted( $numeric ) {
	if ( function_exists( 'get_woocommerce_price_format' ) ) {

		$args = apply_filters(
			'wc_price_args',
			wp_parse_args(
				[],
				array(
					'ex_tax_label'       => false,
					'currency'           => '',
					'decimal_separator'  => wc_get_price_decimal_separator(),
					'thousand_separator' => wc_get_price_thousand_separator(),
					'decimals'           => wc_get_price_decimals(),
					'price_format'       => get_woocommerce_price_format(),
				)
			)
		);

		$bedrag = (float) $numeric * SprayPay()->rate;

		return apply_filters(
			'formatted_woocommerce_price',
			number_format( $bedrag, $args['decimals'], $args['decimal_separator'], $args['thousand_separator'] ),
			$bedrag,
			$args['decimals'],
			$args['decimal_separator'],
			$args['thousand_separator']
		);

	} else {
		return '0.00';
	}
}

/**
 * Format number value and turn into a price like value according to WC settings
 *
 * @param $number
 *
 * @return string
 */
function spraypay_format_price( $number ) {
	$formatted = wc_price( $number );

	return $formatted;
}

/**
 * Check displaying condition
 *
 */
function spray_pay_should_display( $price, $settings ) {
	return $price > $settings['min_amount'] && $price < $settings['max_amount'];
}

/**
 * Check whether widget must be displayed on the product page or not.
 * And actually display it if needed.
 *
 */
function spray_pay_display_on_single_product() {
	global $product;
	$spray_pay_settings = get_option( 'spray_pay_settings' );
	$price              = $product->get_price();
	$should_display     = spray_pay_should_display( $price, $spray_pay_settings );

	if ( 'variable' !== $product->get_type() && ! $should_display ) {
		return;
	}

	$bedrag_formatted = spray_pay_formatted( $price );

	$data = [
		'appearance'       => $spray_pay_settings['appearance'],
		'min_amount'       => $spray_pay_settings['min_amount'],
		'max_amount'       => $spray_pay_settings['max_amount'],
		'display_as_text'  => SprayPay()->widget_get_display_text_tmpl( $spray_pay_settings ),
		'bedrag_formatted' => spraypay_format_price( $bedrag_formatted ),
		'popup_content'    => ''
	];

	if ( 'variable' === $product->get_type() ) {
		spray_pay_widget_tmpl_js( $data );
	} else {
		spray_pay_widget_tmpl( $data );
	}
}

/**
 * spray_pay_output_widget_tmpl
 */
function spray_pay_output_widget_tmpl() {
	global $product;

	if (!$product) {
		return;
	}

	$spray_pay_settings = get_option( 'spray_pay_settings' );
	$price              = $product->get_price();
	$should_display     = spray_pay_should_display( $price, $spray_pay_settings );

	if ( 'variable' !== $product->get_type() && ! $should_display ) {
		return;
	}

	$bedrag_formatted = spray_pay_formatted( $price );

	$data = [
		'appearance'       => $spray_pay_settings['appearance'],
		'min_amount'       => $spray_pay_settings['min_amount'],
		'max_amount'       => $spray_pay_settings['max_amount'],
		'display_as_text'  => SprayPay()->widget_get_display_text_tmpl( $spray_pay_settings ),
		'bedrag_formatted' => spraypay_format_price( $bedrag_formatted ),
		'popup_content'    => ''
	];

	spray_pay_widget_tmpl_js( $data );
}

/**
 * Main JS template for SprayPay widget. Take price/total (for cart/checkout) and output
 * the final text.
 *
 */
function spray_pay_widget_tmpl_js( $data ) {
	$uid        = uniqid();
	$final_text = $data['display_as_text'];
	$final_text = wp_kses( $final_text, array(
		'em'     => array(),
		'strong' => array(),
	) );
	$tmpl       = '';

	$special_text  = esc_html__( 'Let op! Geld lenen kost geld.', 'spraypay' );
	$svg_spray_pay = '<svg data-name="Laag 1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 103.27971 41.21303"><defs><style>.cls-1{fill:#00358e;}.cls-2{fill:#00a9ce;}.cls-3{fill:url(#Naamloos_verloop_9);}.cls-4{fill:url(#Naamloos_verloop_9-2);}.cls-5{fill:url(#Naamloos_verloop_9-3);}.cls-6{fill:url(#Naamloos_verloop_9-4);}.cls-7{fill:url(#Naamloos_verloop_9-5);}.cls-8{fill:url(#Naamloos_verloop_9-6);}.cls-9{fill:url(#Naamloos_verloop_9-7);}.cls-10{fill:url(#Naamloos_verloop_9-8);}.cls-11{fill:url(#Naamloos_verloop_9-9);}.cls-12{fill:url(#Naamloos_verloop_9-10);}.cls-13{fill:url(#Naamloos_verloop_9-11);}.cls-14{fill:url(#Naamloos_verloop_9-12);}</style><linearGradient id="Naamloos_verloop_9" x1="30.95407" y1="5.87323" x2="72.30002" y2="5.87323" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#00358e"/><stop offset="1" stop-color="#00a9ce"/></linearGradient><linearGradient id="Naamloos_verloop_9-2" x1="30.95407" y1="7.44545" x2="72.30002" y2="7.44545" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-3" x1="30.95407" y1="8.52974" x2="72.30002" y2="8.52974" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-4" x1="30.95407" y1="9.19838" x2="72.30002" y2="9.19838" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-5" x1="30.95407" y1="9.45139" x2="72.30002" y2="9.45139" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-6" x1="30.95407" y1="9.34296" x2="72.30002" y2="9.34296" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-7" x1="30.95407" y1="8.89117" x2="72.30002" y2="8.89117" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-8" x1="30.95407" y1="8.09602" x2="72.30002" y2="8.09602" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-9" x1="30.95407" y1="6.93945" x2="72.30002" y2="6.93945" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-10" x1="30.95407" y1="5.36723" x2="72.30002" y2="5.36723" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-11" x1="30.95407" y1="3.37937" x2="72.30002" y2="3.37937" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-12" x1="30.95407" y1="0.90357" x2="72.30002" y2="0.90357" xlink:href="#Naamloos_verloop_9"/></defs><path class="cls-1" d="M5.94449,32.14217a8.28764,8.28764,0,0,1-3.26779-.56065A4.69029,4.69029,0,0,1,.708,30.11422,3.40859,3.40859,0,0,1,0,28.18558a.39357.39357,0,0,1,.12735-.28513A.41345.41345,0,0,1,.4325,27.7723H2.913a.74717.74717,0,0,1,.42289.09932,1.06382,1.06382,0,0,1,.2659.25469,2.317,2.317,0,0,0,.44292.57187,2.08667,2.08667,0,0,0,.75768.44211,3.42078,3.42078,0,0,0,1.14212.16659,3.36422,3.36422,0,0,0,1.722-.354,1.08372,1.08372,0,0,0,.58067-.96432.92567.92567,0,0,0-.31477-.72884,2.9925,2.9925,0,0,0-1.014-.50138,17.74867,17.74867,0,0,0-1.85976-.46294,11.23133,11.23133,0,0,1-2.54935-.817A3.88619,3.88619,0,0,1,.90505,24.16012a3.87243,3.87243,0,0,1,.12815-4.18245A4.46645,4.46645,0,0,1,2.933,18.50076a7.2085,7.2085,0,0,1,2.893-.53182,7.34206,7.34206,0,0,1,2.39158.35561,5.43413,5.43413,0,0,1,1.742.9451,4.48093,4.48093,0,0,1,1.07325,1.24945,2.8463,2.8463,0,0,1,.38364,1.28789.43656.43656,0,0,1-.10812.28673.38.38,0,0,1-.30516.12655H8.40494a.84235.84235,0,0,1-.374-.07689.71915.71915,0,0,1-.27552-.2563,1.36129,1.36129,0,0,0-.61992-.75928A2.3916,2.3916,0,0,0,5.826,20.80423a2.53008,2.53008,0,0,0-1.348.30435,1.03145,1.03145,0,0,0-.48216.93548.99438.99438,0,0,0,.26511.6888,2.12867,2.12867,0,0,0,.88583.5126,15.27194,15.27194,0,0,0,1.70277.45172,12.94135,12.94135,0,0,1,2.89375.83617,3.71679,3.71679,0,0,1,1.62349,1.30071,3.94248,3.94248,0,0,1-.24589,4.29938A4.87016,4.87016,0,0,1,9.02486,31.62,8.39671,8.39671,0,0,1,5.94449,32.14217Z"/><path class="cls-1" d="M14.34943,31.94514a.46575.46575,0,0,1-.35481-.14737.48976.48976,0,0,1-.13776-.3444V18.65774a.47179.47179,0,0,1,.49257-.49017h5.51119a7.418,7.418,0,0,1,2.8441.49978,4.13719,4.13719,0,0,1,1.89019,1.50735,4.43379,4.43379,0,0,1,.67838,2.53894,4.30007,4.30007,0,0,1-.67838,2.4989,3.99425,3.99425,0,0,1-1.89019,1.45769,7.823,7.823,0,0,1-2.8441.47094H17.51791v4.3122a.47.47,0,0,1-.14738.3444.49709.49709,0,0,1-.36442.14737Zm3.11-7.51912h2.30267a1.98958,1.98958,0,0,0,1.34876-.4341,1.64609,1.64609,0,0,0,.50138-1.31673,1.88552,1.88552,0,0,0-.4325-1.26066,1.76305,1.76305,0,0,0-1.41764-.511H17.45944Z"/><path class="cls-1" d="M27.65526,31.94514a.46577.46577,0,0,1-.35482-.14737.48976.48976,0,0,1-.13776-.3444V18.65774a.4718.4718,0,0,1,.49258-.49017h5.3534a6.24555,6.24555,0,0,1,4.01586,1.16936,4.01586,4.01586,0,0,1,1.45688,3.31744,4.04526,4.04526,0,0,1-.66957,2.36274,4.19814,4.19814,0,0,1-1.77166,1.45609l2.69673,4.84241a.49.49,0,0,1,.05927.21625.44018.44018,0,0,1-.41328.41328H35.76466a.7257.7257,0,0,1-.551-.18742,1.48462,1.48462,0,0,1-.2563-.3444l-2.2434-4.32982H30.706v4.36987a.47.47,0,0,1-.14737.3444.49838.49838,0,0,1-.36442.14737ZM30.706,24.28826h2.26343a1.907,1.907,0,0,0,1.388-.45332,1.62758,1.62758,0,0,0,.46214-1.22062,1.74021,1.74021,0,0,0-.44291-1.23983,1.85188,1.85188,0,0,0-1.40723-.471H30.706Z"/><path class="cls-1" d="M39.97674,31.94514a.44018.44018,0,0,1-.41328-.41328.71474.71474,0,0,1,.02-.17781l4.62536-12.63544a.792.792,0,0,1,.24589-.38445.75333.75333,0,0,1,.5222-.16659h2.913a.75253.75253,0,0,1,.5214.16659.792.792,0,0,1,.24589.38445l4.60614,12.63544a.39491.39491,0,0,1-.0889.46294.41657.41657,0,0,1-.30436.12815h-2.4212a.60436.60436,0,0,1-.44292-.14737.73376.73376,0,0,1-.18741-.26591l-.76729-2.00713h-5.2557l-.74806,2.00713a.78119.78119,0,0,1-.177.26591.62967.62967,0,0,1-.47255.14737Zm4.62616-5.25569h3.661L46.433,21.493Z"/><path class="cls-1" d="M57.31764,31.94514a.50362.50362,0,0,1-.49177-.49177V27.22126L52.259,18.7955c-.01281-.03845-.02643-.07369-.03924-.10733a.2967.2967,0,0,1-.01922-.10732.391.391,0,0,1,.12734-.28513.41347.41347,0,0,1,.30516-.12815h2.46045a.67238.67238,0,0,1,.46294.14737.925.925,0,0,1,.22586.26591l2.81526,5.07788L61.432,18.58085a.92479.92479,0,0,1,.22586-.26591.671.671,0,0,1,.46293-.14737h2.46046a.38317.38317,0,0,1,.29554.12815.40611.40611,0,0,1,.11774.28513.56883.56883,0,0,1-.00962.10732.99791.99791,0,0,1-.02963.10733L60.3884,27.22126v4.23211a.47.47,0,0,1-.14737.3444.49842.49842,0,0,1-.36443.14737Z"/><path class="cls-2" d="M67.17947,31.94514a.46573.46573,0,0,1-.35481-.14737.48971.48971,0,0,1-.13776-.3444V18.65774a.47179.47179,0,0,1,.49257-.49017h5.51119a7.41786,7.41786,0,0,1,2.84409.49978,4.13709,4.13709,0,0,1,1.89019,1.50735,4.43372,4.43372,0,0,1,.67839,2.53894,4.3,4.3,0,0,1-.67839,2.4989,3.99416,3.99416,0,0,1-1.89019,1.45769,7.82294,7.82294,0,0,1-2.84409.47094H70.34794v4.3122a.47.47,0,0,1-.14737.3444.49709.49709,0,0,1-.36442.14737Zm3.11-7.51912h2.30267a1.98959,1.98959,0,0,0,1.34877-.4341,1.64613,1.64613,0,0,0,.50138-1.31673,1.88552,1.88552,0,0,0-.4325-1.26066,1.76308,1.76308,0,0,0-1.41765-.511H70.28947Z"/><path class="cls-2" d="M78.26111,31.94514a.44018.44018,0,0,1-.41328-.41328.71425.71425,0,0,1,.02-.17781l4.62536-12.63544a.792.792,0,0,1,.24588-.38445.75337.75337,0,0,1,.52221-.16659h2.913a.75254.75254,0,0,1,.5214.16659.792.792,0,0,1,.24588.38445l4.60614,12.63544a.39486.39486,0,0,1-.0889.46294.41656.41656,0,0,1-.30435.12815H88.73325a.60432.60432,0,0,1-.44291-.14737.73368.73368,0,0,1-.18742-.26591l-.76729-2.00713H82.07994l-.74807,2.00713a.78129.78129,0,0,1-.177.26591.62967.62967,0,0,1-.47255.14737Zm4.62617-5.25569h3.661L84.7174,21.493Z"/><path class="cls-2" d="M95.60281,31.94514a.50364.50364,0,0,1-.49177-.49177V27.22126L90.54415,18.7955c-.01281-.03845-.02643-.07369-.03924-.10733a.29671.29671,0,0,1-.01923-.10732.39092.39092,0,0,1,.12735-.28513.41346.41346,0,0,1,.30515-.12815h2.46046a.67237.67237,0,0,1,.46293.14737.92479.92479,0,0,1,.22586.26591l2.81527,5.07788,2.83448-5.07788a.925.925,0,0,1,.22587-.26591.671.671,0,0,1,.46293-.14737h2.46045a.38319.38319,0,0,1,.29555.12815.4061.4061,0,0,1,.11773.28513.56886.56886,0,0,1-.00961.10732,1.00258,1.00258,0,0,1-.02963.10733l-4.5669,8.42576v4.23211a.47.47,0,0,1-.14737.3444.49838.49838,0,0,1-.36442.14737Z"/><path class="cls-1" d="M20.9822,41.213a1.91814,1.91814,0,0,1-.9669-.22438,1.479,1.479,0,0,1-.59583-.626,2.19732,2.19732,0,0,1-.224-.923q-.00653-.30172-.00653-.63612t.00653-.63541a2.1929,2.1929,0,0,1,.224-.92732,1.48151,1.48151,0,0,1,.59909-.62234,1.92331,1.92331,0,0,1,.96364-.22438,2.04189,2.04189,0,0,1,.78971.13724,1.68111,1.68111,0,0,1,.53556.34131,1.52833,1.52833,0,0,1,.3079.41174.95183.95183,0,0,1,.10711.34783.10822.10822,0,0,1-.03377.09731.151.151,0,0,1-.10675.037h-.14741a.11035.11035,0,0,1-.08714-.0305.327.327,0,0,1-.05338-.10385,1.21215,1.21215,0,0,0-.22438-.39794,1.187,1.187,0,0,0-.42155-.31443,1.565,1.565,0,0,0-.6659-.12418,1.41558,1.41558,0,0,0-.9669.3246,1.44283,1.44283,0,0,0-.39831,1.08128q-.02016.60235,0,1.20472a1.44391,1.44391,0,0,0,.39831,1.07692,1.40688,1.40688,0,0,0,.9669.32823,1.62574,1.62574,0,0,0,.70947-.15032,1.12989,1.12989,0,0,0,.49525-.46185,1.5629,1.5629,0,0,0,.18082-.793V39.065H21.20332a.13824.13824,0,0,1-.10711-.04357.15662.15662,0,0,1-.04031-.11038v-.09368a.15381.15381,0,0,1,.04031-.114.14378.14378,0,0,1,.10711-.03994h1.432a.13974.13974,0,0,1,.15394.154v.58893a2.02864,2.02864,0,0,1-.211.9433,1.51082,1.51082,0,0,1-.61543.63613A1.97337,1.97337,0,0,1,20.9822,41.213Z"/><path class="cls-1" d="M24.30154,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h2.61024a.13974.13974,0,0,1,.15395.154v.10021a.14429.14429,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067H24.576v1.70651h2.18833a.13975.13975,0,0,1,.154.15395v.10021a.14431.14431,0,0,1-.04031.10675.1531.1531,0,0,1-.11364.04066H24.576v1.77332h2.38911a.13974.13974,0,0,1,.15395.154v.10021a.14316.14316,0,0,1-.0403.10675.15308.15308,0,0,1-.11365.04067Z"/><path class="cls-1" d="M29.85606,41.213a2.18847,2.18847,0,0,1-.92007-.17428,1.43846,1.43846,0,0,1-.57876-.44805,1.04684,1.04684,0,0,1-.21422-.58239.12952.12952,0,0,1,.03994-.09368.136.136,0,0,1,.10058-.03994h.13361a.13356.13356,0,0,1,.10384.03994.165.165,0,0,1,.04357.09368.80166.80166,0,0,0,.16739.3718,1.04657,1.04657,0,0,0,.415.30717,1.72939,1.72939,0,0,0,.70911.12418,1.54794,1.54794,0,0,0,.9571-.23746.77225.77225,0,0,0,.30136-.639.59865.59865,0,0,0-.15758-.43208,1.38386,1.38386,0,0,0-.47819-.2941q-.32133-.13071-.82348-.2912a4.85906,4.85906,0,0,1-.78282-.31806,1.011,1.011,0,0,1-.59582-1.00067,1.07868,1.07868,0,0,1,.18081-.61216,1.23851,1.23851,0,0,1,.52539-.43135,1.97319,1.97319,0,0,1,.83982-.16121,2.02212,2.02212,0,0,1,.68951.10747,1.44229,1.44229,0,0,1,.48835.28466,1.27856,1.27856,0,0,1,.29446.38124.96962.96962,0,0,1,.10711.398.14857.14857,0,0,1-.0334.09077.12687.12687,0,0,1-.10711.04357h-.134a.194.194,0,0,1-.08351-.02687.138.138,0,0,1-.06354-.10747.77019.77019,0,0,0-.35147-.5519,1.37616,1.37616,0,0,0-.80642-.21785,1.51573,1.51573,0,0,0-.80968.19462.7494.7494,0,0,0-.17392,1.04714,1.15715,1.15715,0,0,0,.44151.30136q.30118.12963.77628.28394a6.24636,6.24636,0,0,1,.83.32169,1.23989,1.23989,0,0,1,.48836.39141,1.02727,1.02727,0,0,1,.16084.5991,1.16146,1.16146,0,0,1-.204.69277,1.28148,1.28148,0,0,1-.57913.435A2.406,2.406,0,0,1,29.85606,41.213Z"/><path class="cls-1" d="M32.98151,41.14623a.14481.14481,0,0,1-.10711-.04067.143.143,0,0,1-.03994-.10675V36.61562a.15369.15369,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h1.62627a1.95,1.95,0,0,1,.81332.15685,1.201,1.201,0,0,1,.53519.46548,1.62175,1.62175,0,0,1,0,1.5257,1.19508,1.19508,0,0,1-.53519.46475,1.93833,1.93833,0,0,1-.81332.15758H33.256v1.76678a.14319.14319,0,0,1-.0403.10675.15309.15309,0,0,1-.11365.04067Zm.2745-2.31578h1.31837a1.271,1.271,0,0,0,.86669-.25416,1.07793,1.07793,0,0,0,0-1.45888,1.26727,1.26727,0,0,0-.86669-.25416H33.256Z"/><path class="cls-1" d="M37.519,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h1.55946a1.7438,1.7438,0,0,1,1.12085.334,1.22494,1.22494,0,0,1,.41828,1.01737A1.29636,1.29636,0,0,1,40.35,38.67a1.34165,1.34165,0,0,1-.74287.435l1.07728,1.83359a.16773.16773,0,0,1,.02033.07334.12615.12615,0,0,1-.0403.09368.12888.12888,0,0,1-.09368.04067h-.08024a.20782.20782,0,0,1-.16049-.05737.69982.69982,0,0,1-.09367-.12345l-1.06421-1.80019H37.79351v1.83359a.14316.14316,0,0,1-.0403.10675.15308.15308,0,0,1-.11365.04067Zm.27449-2.38258h1.25157a1.33193,1.33193,0,0,0,.86669-.23746,1.03561,1.03561,0,0,0,0-1.42549,1.33193,1.33193,0,0,0-.86669-.23745H37.79351Z"/><path class="cls-1" d="M42.13677,41.14623a.1448.1448,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14434.14434,0,0,1,.10711-.03994H44.747a.13974.13974,0,0,1,.154.154v.10021a.14429.14429,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067H42.41126v1.70651h2.18833a.13974.13974,0,0,1,.154.15395v.10021a.14435.14435,0,0,1-.0403.10675.15313.15313,0,0,1-.11365.04066H42.41126v1.77332h2.38912a.13975.13975,0,0,1,.154.154v.10021a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><path class="cls-1" d="M46.43318,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.60836a.13753.13753,0,0,1,.14705-.14669h.12708a.13807.13807,0,0,1,.14742.14669v4.39045a.13914.13914,0,0,1-.14742.14742Z"/><path class="cls-1" d="M48.44759,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h1.42548a2.4578,2.4578,0,0,1,1.111.207,1.19824,1.19824,0,0,1,.57223.61289,2.61587,2.61587,0,0,1,.17718.98687c.00436.20043.0069.37834.0069.53229s-.00254.33114-.0069.53156a2.83,2.83,0,0,1-.18045,1.01737,1.1425,1.1425,0,0,1-.56242.5991,2.45963,2.45963,0,0,1-1.08418.19752Zm.27449-.40158h1.151a2.05382,2.05382,0,0,0,.84672-.14378.87282.87282,0,0,0,.44842-.46185,2.2298,2.2298,0,0,0,.14378-.84018c.00436-.13362.00653-.25053.00653-.35147v-.29773c0-.098-.00217-.21423-.00653-.34784a1.59719,1.59719,0,0,0-.3413-1.08781,1.50325,1.50325,0,0,0-1.131-.35074H48.72208Z"/><path class="cls-1" d="M55.37421,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994H57.121a1.55017,1.55017,0,0,1,.76611.167,1.065,1.065,0,0,1,.43861.43861,1.26375,1.26375,0,0,1,.14051.59183,1.21423,1.21423,0,0,1-.0904.49235.99559.99559,0,0,1-.22766.33114,1.17293,1.17293,0,0,1-.27086.19388,1.3033,1.3033,0,0,1,.47492.42845,1.21089,1.21089,0,0,1,.20768.716,1.37668,1.37668,0,0,1-.15722.639,1.24356,1.24356,0,0,1-.46874.49525,1.44122,1.44122,0,0,1-.76612.191Zm.2745-2.65054h1.38517a1.127,1.127,0,0,0,.753-.22076.76726.76726,0,0,0,.25743-.6158.70857.70857,0,0,0-.25743-.59546,1.20894,1.20894,0,0,0-.753-.20042H55.64871Zm0,2.249h1.45235a1.05891,1.05891,0,0,0,.76611-.26142.9486.9486,0,0,0,0-1.32818,1.07021,1.07021,0,0,0-.76611-.25779H55.64871Z"/><path class="cls-1" d="M60.0791,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h2.61024a.13975.13975,0,0,1,.154.154v.10021a.1443.1443,0,0,1-.04031.10675.15365.15365,0,0,1-.11364.04067H60.35359v1.70651h2.18833a.13974.13974,0,0,1,.154.15395v.10021a.14431.14431,0,0,1-.0403.10675.15313.15313,0,0,1-.11365.04066H60.35359v1.77332h2.38912a.13974.13974,0,0,1,.15395.154v.10021a.14319.14319,0,0,1-.0403.10675.15309.15309,0,0,1-.11365.04067Z"/><path class="cls-1" d="M65.39942,41.14623a.13859.13859,0,0,1-.14705-.14742V36.86325H63.9271a.13859.13859,0,0,1-.14705-.14742v-.10021a.15515.15515,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h3.06519a.13975.13975,0,0,1,.154.154v.10021a.1443.1443,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067H65.67392v4.13556a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><path class="cls-1" d="M67.45413,41.14623a.12886.12886,0,0,1-.09367-.04067.12616.12616,0,0,1-.04031-.09368.23173.23173,0,0,1,.01344-.07334L69.027,36.59529a.22548.22548,0,0,1,.07007-.10022.19861.19861,0,0,1,.12382-.0334h.22765a.19861.19861,0,0,1,.12382.0334.22833.22833,0,0,1,.07007.10022l1.69344,4.34325a.24091.24091,0,0,1,.01307.07334.1258.1258,0,0,1-.03994.09368.12884.12884,0,0,1-.09367.04067h-.134a.1278.1278,0,0,1-.10021-.037.30041.30041,0,0,1-.04684-.06318l-.415-1.0711H68.15017l-.415,1.0711a.15349.15349,0,0,1-.04357.06318.13931.13931,0,0,1-.10348.037Zm.85653-1.5729h2.04781l-1.02391-2.63674Z"/><path class="cls-1" d="M72.62051,41.14623a.1448.1448,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.60836a.13753.13753,0,0,1,.147-.14669h.12708a.13805.13805,0,0,1,.14741.14669v4.13629h2.30887a.13974.13974,0,0,1,.154.154v.10021a.14316.14316,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067Z"/><path class="cls-1" d="M76.62246,41.14623a.1448.1448,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14434.14434,0,0,1,.10711-.03994h2.61023a.13974.13974,0,0,1,.15395.154v.10021a.14429.14429,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067H76.897v1.70651h2.18833a.13974.13974,0,0,1,.154.15395v.10021a.14435.14435,0,0,1-.0403.10675.15313.15313,0,0,1-.11365.04066H76.897v1.77332h2.38912a.13975.13975,0,0,1,.154.154v.10021a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><path class="cls-1" d="M80.91887,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h.14052a.1362.1362,0,0,1,.10057.0334.23558.23558,0,0,1,.03994.04648l2.46972,3.77466V36.61562a.15515.15515,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h.12055a.13926.13926,0,0,1,.15358.154v4.37666a.15638.15638,0,0,1-.03994.11038.13877.13877,0,0,1-.10711.04357h-.147a.12613.12613,0,0,1-.09694-.03341c-.02033-.02251-.03486-.03776-.04357-.0472l-2.46282-3.76086v3.694a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><rect class="cls-3" x="30.85765" width="1.80715" height="11.74646" rx="0.90357"/><rect class="cls-4" x="34.47195" y="2.02401" width="1.80715" height="10.84289" rx="0.90357"/><rect class="cls-5" x="38.08624" y="3.56008" width="1.80715" height="9.93932" rx="0.90357"/><rect class="cls-6" x="41.70054" y="4.68051" width="1.80715" height="9.03574" rx="0.90357"/><rect class="cls-7" x="45.31484" y="5.3853" width="1.80715" height="8.13217" rx="0.90357"/><rect class="cls-8" x="48.92913" y="5.72866" width="1.80715" height="7.22859" rx="0.90357"/><rect class="cls-9" x="52.54343" y="5.72866" width="1.80715" height="6.32502" rx="0.90357"/><rect class="cls-10" x="56.15773" y="5.3853" width="1.80715" height="5.42144" rx="0.90357"/><rect class="cls-11" x="59.77202" y="4.68051" width="1.80715" height="4.51787" rx="0.90357"/><rect class="cls-12" x="63.38632" y="3.56008" width="1.80715" height="3.6143" rx="0.90357"/><rect class="cls-13" x="67.00062" y="2.02401" width="1.80715" height="2.71072" rx="0.90357"/><rect class="cls-14" x="70.61491" width="1.80715" height="1.80715" rx="0.90357"/></svg>';

	switch ( $data['appearance'] ) :
		case 'branded' :
			$tmpl .= '<div class="sprayPayWidget noBg withLogo" data-modal-id="sprayPayModal_' . esc_attr( $uid ) . '" data-trigger="sprayPayModal">
<i class="logo">' . $svg_spray_pay . '</i>
<p>' . $final_text . '<br><b>' . $special_text . '</b></p><i class="info">i</i></div>';
			break;
		case 'label' :
			$tmpl .= '<div class="sprayPayWidget noBg" data-modal-id="sprayPayModal_' . esc_attr( $uid ) . '" data-trigger="sprayPayModal">
<p>' . $final_text . '<br><b>' . $special_text . '</b></p><i class="info">i</i></div>';
			break;
	endswitch;

	$tmpl .= '<br>';

	$tmpl .= spray_pay_modal_html( $data, $svg_spray_pay, $uid );

	echo "<template id='sprayPay_widget_tmpl'>$tmpl</template>";
}

/**
 * @param $data
 * @param $svg_spray_pay
 * @param $uid
 *
 * @return string
 */
function spray_pay_modal_html( $data, $svg_spray_pay, $uid ) {
	$p1 = wp_kses( __( 'Betaal jouw aankoop in <strong>12,18,24 of 36 maanden</strong>.', 'spraypay' ),
		array(
			'em'     => array(),
			'strong' => array(),
		)
	);

	$p2 = wp_kses( sprintf( __( 'Beschikbaar voor aankopen tussen de <strong>€%s en €%s,-</strong>', 'spraypay' ), $data['min_amount'], $data['max_amount'] ),
		array(
			'em'     => array(),
			'strong' => array(),
		)
	);
	$p3 = wp_kses( __( '<strong>Volledig of extra aflossen</strong> is boetevrij. Jij bepaalt dus de looptijd!', 'spraypay' ),
		array(
			'em'     => array(),
			'strong' => array(),
		)
	);

	$p4 = wp_kses( __( 'Een <strong>vast maandbedrag</strong>. Na 30 dagen schrijven wij het eerste maandbedrag af.', 'spraypay' ),
		array(
			'em'     => array(),
			'strong' => array(),
		)
	);

	$p5 = wp_kses( __( '<strong>Aanvragen</strong> via het afrekenproces.', 'spraypay' ),
		array(
			'em'     => array(),
			'strong' => array(),
		)
	);

	$p6 = wp_kses( sprintf( __( 'Wil jij meer informatie over SprayPay: Ga naar %s', 'spraypay' ), '<a href="https://www.spraypay.nl" target="_blank">www.spraypay.nl</a>' ),
		array(
			'em'     => array(),
			'strong' => array(),
			'a'      => array(
				'href'   => array(),
				'target' => array()
			)
		)
	);

	return '<div class="modal micromodal-slide" id="sprayPayModal_' . esc_attr( $uid ) . '" aria-hidden="true">
    <div class="modal__overlay" tabindex="-1" data-micromodal-close>
      <div class="modal__container" role="dialog" aria-modal="true" aria-label="' . esc_attr__( 'SprayPay modaal', 'spraypay' ) . '">
      <header class="modal__header">
          <button class="modal__close" aria-label="' . esc_attr__( 'Sluiten', 'spraypay' ) . '" data-micromodal-close></button>
        </header>
      <div class="sp-note">
            <svg height="72.919998" viewBox="0 0 1366.9467 72.919998" width="1366.9467" xmlns="http://www.w3.org/2000/svg">
                <g transform="matrix(.13333333 0 0 -.13333333 0 72.92)"><path d="m10247.1 5h-10242.1v536.895h10242.1z" fill="#fff"/><path d="m10247.1 5h-10242.1v536.895h10242.1z" fill="none" stroke="#050301" stroke-width="10"/><g fill="#050301"><path d="m3376.66 190.039v184.336h37.53v-153.016h93.31v-31.32z"/><path d="m3608.8 268.898c-.25 10.313-2.92 18.153-7.98 23.516-5.08 5.371-11.24 8.055-18.52 8.055-7.77 0-14.19-2.832-19.27-8.496-5.07-5.664-7.56-13.36-7.48-23.075zm-2.03-36.007 35.5-5.957c-4.56-13.016-11.77-22.93-21.62-29.727-9.84-6.805-22.16-10.215-36.95-10.215-23.41 0-40.74 7.656-51.98 22.949-8.88 12.258-13.31 27.727-13.31 46.407 0 22.316 5.83 39.785 17.49 52.422 11.67 12.636 26.41 18.957 44.25 18.957 20.03 0 35.84-6.614 47.41-19.844 11.59-13.223 17.12-33.488 16.61-60.793h-89.25c.26-10.567 3.13-18.789 8.62-24.656 5.49-5.879 12.34-8.809 20.54-8.809 5.58 0 10.27 1.523 14.07 4.559 3.81 3.046 6.68 7.949 8.62 14.707"/><path d="m3729.76 324.68v-28.399h-24.34v-54.258c0-10.988.23-17.394.69-19.21.47-1.817 1.53-3.321 3.17-4.5 1.65-1.184 3.66-1.778 6.03-1.778 3.29 0 8.07 1.141 14.32 3.426l3.05-27.637c-8.29-3.554-17.67-5.332-28.15-5.332-6.42 0-12.22 1.086-17.37 3.235-5.16 2.156-8.94 4.949-11.34 8.367-2.42 3.429-4.09 8.058-5.01 13.886-.77 4.141-1.15 12.512-1.15 25.098v58.703h-16.35v28.399h16.35v26.758l35.76 20.789v-47.547z"/><path d="m3818.54 257.363c0-13.359 3.17-23.582 9.51-30.683 6.34-7.098 14.16-10.653 23.45-10.653 9.3 0 17.1 3.555 23.39 10.653 6.3 7.101 9.45 17.414 9.45 30.937 0 13.184-3.15 23.321-9.45 30.422-6.29 7.098-14.09 10.652-23.39 10.652-9.29 0-17.11-3.554-23.45-10.652-6.34-7.101-9.51-17.324-9.51-30.676zm-36.51 1.895c0 11.836 2.91 23.293 8.75 34.367 5.83 11.063 14.09 19.52 24.78 25.352 10.69 5.828 22.63 8.75 35.82 8.75 20.36 0 37.06-6.614 50.08-19.844 13.01-13.223 19.52-29.942 19.52-50.137 0-20.371-6.57-37.258-19.72-50.656-13.14-13.399-29.68-20.098-49.63-20.098-12.34 0-24.11 2.793-35.31 8.371-11.2 5.575-19.71 13.758-25.54 24.532-5.84 10.781-8.75 23.906-8.75 39.363"/><path d="m3972.71 259.641c0-15.129 3.01-26.301 9.01-33.528 6-7.226 13.31-10.84 21.93-10.84 8.28 0 15.17 3.313 20.67 9.954 5.49 6.628 8.24 17.507 8.24 32.644 0 14.113-2.83 24.59-8.5 31.438-5.66 6.843-12.67 10.273-21.04 10.273-8.71 0-15.94-3.359-21.68-10.078-5.75-6.719-8.63-16.672-8.63-29.863zm-35.24 65.039h33.22v-19.778c4.31 6.758 10.14 12.258 17.49 16.485 7.36 4.218 15.51 6.34 24.47 6.34 15.64 0 28.91-6.133 39.81-18.391 10.9-12.254 16.36-29.324 16.36-51.211 0-22.488-5.5-39.961-16.49-52.43-10.98-12.461-24.29-18.703-39.93-18.703-7.44 0-14.18 1.485-20.22 4.446-6.05 2.957-12.41 8.027-19.08 15.214v-67.832h-35.63z"/><path d="m4092.92 190.039v35.625h35.62v-35.625zm7.73 47.922-9.25 94.324v43.613h38.54v-43.613l-9.13-94.324z"/><path d="m4300.86 258.379v31.309h80.89v-74.043c-7.86-7.598-19.25-14.305-34.17-20.086-14.91-5.793-30.02-8.692-45.32-8.692-19.44 0-36.38 4.082-50.83 12.235-14.45 8.156-25.32 19.824-32.59 34.992-7.27 15.176-10.91 31.679-10.91 49.511 0 19.356 4.07 36.551 12.17 51.602 8.13 15.039 20 26.582 35.63 34.609 11.92 6.172 26.76 9.258 44.51 9.258 23.07 0 41.09-4.844 54.06-14.523 12.98-9.676 21.33-23.047 25.04-40.125l-37.26-6.973c-2.62 9.129-7.55 16.336-14.78 21.621-7.23 5.281-16.24 7.918-27.06 7.918-16.41 0-29.43-5.195-39.12-15.594-9.67-10.39-14.51-25.82-14.51-46.269 0-22.063 4.9-38.606 14.7-49.641 9.81-11.023 22.66-16.543 38.54-16.543 7.87 0 15.74 1.543 23.65 4.629 7.9 3.086 14.69 6.828 20.35 11.223v23.582z"/><path d="m4485.73 268.898c-.26 10.313-2.92 18.153-7.99 23.516-5.08 5.371-11.24 8.055-18.52 8.055-7.77 0-14.2-2.832-19.26-8.496-5.07-5.664-7.57-13.36-7.48-23.075zm-2.03-36.007 35.49-5.957c-4.56-13.016-11.76-22.93-21.61-29.727-9.84-6.805-22.16-10.215-36.95-10.215-23.42 0-40.74 7.656-51.99 22.949-8.87 12.258-13.3 27.727-13.3 46.407 0 22.316 5.82 39.785 17.49 52.422 11.67 12.636 26.41 18.957 44.25 18.957 20.02 0 35.84-6.614 47.41-19.844 11.58-13.223 17.12-33.488 16.61-60.793h-89.26c.25-10.567 3.13-18.789 8.62-24.656 5.5-5.879 12.34-8.809 20.54-8.809 5.59 0 10.27 1.523 14.08 4.559 3.8 3.046 6.67 7.949 8.62 14.707"/><path d="m4539.75 190.039v185.859h35.63v-185.859z"/><path d="m4629.9 260.273c0-14.363 1.98-24.765 5.95-31.179 5.76-9.309 13.78-13.946 24.1-13.946 8.19 0 15.17 3.485 20.91 10.457 5.75 6.973 8.62 17.383 8.62 31.25 0 15.469-2.79 26.602-8.36 33.411-5.59 6.797-12.73 10.203-21.43 10.203-8.45 0-15.52-3.36-21.23-10.078-5.71-6.719-8.56-16.758-8.56-30.118zm95.09-70.234h-33.09v19.777c-5.51-7.687-11.99-13.418-19.47-17.179-7.48-3.758-15.02-5.645-22.63-5.645-15.46 0-28.72 6.242-39.75 18.703-11.02 12.469-16.54 29.864-16.54 52.176 0 22.813 5.36 40.168 16.1 52.043s24.3 17.813 40.7 17.813c15.05 0 28.05-6.262 39.05-18.762v66.933h35.63z"/><path d="m4821.86 190.039v185.859h35.63v-185.859z"/><path d="m4968.79 268.898c-.25 10.313-2.91 18.153-7.98 23.516-5.07 5.371-11.23 8.055-18.51 8.055-7.78 0-14.2-2.832-19.27-8.496-5.08-5.664-7.57-13.36-7.48-23.075zm-2.03-36.007 35.51-5.957c-4.57-13.016-11.78-22.93-21.62-29.727-9.84-6.805-22.17-10.215-36.95-10.215-23.42 0-40.75 7.656-51.99 22.949-8.87 12.258-13.31 27.727-13.31 46.407 0 22.316 5.83 39.785 17.5 52.422 11.66 12.636 26.41 18.957 44.24 18.957 20.04 0 35.84-6.614 47.42-19.844 11.59-13.223 17.11-33.488 16.61-60.793h-89.25c.25-10.567 3.12-18.789 8.62-24.656 5.49-5.879 12.33-8.809 20.54-8.809 5.57 0 10.26 1.523 14.07 4.559 3.81 3.046 6.68 7.949 8.61 14.707"/><path d="m5150.48 190.039h-35.62v68.711c0 14.543-.76 23.945-2.29 28.215-1.51 4.265-3.99 7.586-7.41 9.949-3.43 2.363-7.54 3.555-12.36 3.555-6.17 0-11.71-1.699-16.61-5.078-4.91-3.379-8.27-7.86-10.08-13.438-1.82-5.574-2.73-15.887-2.73-30.926v-60.988h-35.62v134.641h33.08v-19.778c11.76 15.215 26.55 22.825 44.38 22.825 7.86 0 15.04-1.418 21.55-4.25 6.52-2.832 11.44-6.446 14.78-10.84 3.34-4.395 5.66-9.383 6.97-14.961 1.31-5.574 1.96-13.563 1.96-23.965z"/><path d="m5256.24 268.898c-.26 10.313-2.91 18.153-7.99 23.516-5.08 5.371-11.25 8.055-18.52 8.055-7.77 0-14.2-2.832-19.26-8.496-5.07-5.664-7.57-13.36-7.49-23.075zm-2.04-36.007 35.51-5.957c-4.57-13.016-11.78-22.93-21.62-29.727-9.84-6.805-22.17-10.215-36.95-10.215-23.42 0-40.74 7.656-51.99 22.949-8.87 12.258-13.31 27.727-13.31 46.407 0 22.316 5.83 39.785 17.49 52.422 11.67 12.636 26.42 18.957 44.25 18.957 20.04 0 35.84-6.614 47.42-19.844 11.57-13.223 17.11-33.488 16.61-60.793h-89.26c.25-10.567 3.12-18.789 8.63-24.656 5.49-5.879 12.33-8.809 20.53-8.809 5.58 0 10.27 1.523 14.08 4.559 3.79 3.046 6.66 7.949 8.61 14.707"/><path d="m5432.72 190.039h-35.63v68.711c0 14.543-.76 23.945-2.27 28.215-1.52 4.265-3.99 7.586-7.42 9.949-3.42 2.363-7.54 3.555-12.37 3.555-6.16 0-11.7-1.699-16.6-5.078s-8.26-7.86-10.08-13.438c-1.82-5.574-2.72-15.887-2.72-30.926v-60.988h-35.63v134.641h33.09v-19.778c11.75 15.215 26.53 22.825 44.38 22.825 7.86 0 15.03-1.418 21.55-4.25 6.5-2.832 11.42-6.446 14.76-10.84 3.34-4.395 5.67-9.383 6.98-14.961 1.31-5.574 1.96-13.563 1.96-23.965z"/><path d="m5508.57 190.039v185.859h35.62v-98.632l41.71 47.414h43.87l-46.02-49.192 49.31-85.449h-38.41l-33.85 60.481-16.61-17.375v-43.106z"/><path d="m5666.94 257.363c0-13.359 3.16-23.582 9.5-30.683 6.34-7.098 14.16-10.653 23.46-10.653 9.29 0 17.09 3.555 23.39 10.653 6.29 7.101 9.44 17.414 9.44 30.937 0 13.184-3.15 23.321-9.44 30.422-6.3 7.098-14.1 10.652-23.39 10.652-9.3 0-17.12-3.554-23.46-10.652-6.34-7.101-9.5-17.324-9.5-30.676zm-36.52 1.895c0 11.836 2.91 23.293 8.75 34.367 5.83 11.063 14.09 19.52 24.78 25.352 10.69 5.828 22.64 8.75 35.82 8.75 20.37 0 37.06-6.614 50.08-19.844 13.02-13.223 19.52-29.942 19.52-50.137 0-20.371-6.57-37.258-19.71-50.656-13.14-13.399-29.69-20.098-49.64-20.098-12.34 0-24.11 2.793-35.31 8.371-11.2 5.575-19.71 13.758-25.54 24.532-5.84 10.781-8.75 23.906-8.75 39.363"/><path d="m5779.52 228.457 35.75 5.449c1.52-6.933 4.61-12.195 9.26-15.781 4.64-3.594 11.15-5.391 19.52-5.391 9.21 0 16.14 1.692 20.79 5.071 3.12 2.363 4.7 5.535 4.7 9.511 0 2.704-.85 4.942-2.54 6.719-1.78 1.688-5.75 3.25-11.92 4.688-28.74 6.336-46.95 12.129-54.65 17.371-10.64 7.265-15.97 17.363-15.97 30.304 0 11.661 4.61 21.465 13.83 29.415 9.21 7.937 23.49 11.914 42.85 11.914 18.42 0 32.11-3 41.07-9.004 8.96-5.996 15.13-14.875 18.51-26.621l-33.6-6.211c-1.43 5.234-4.16 9.246-8.17 12.039-4.02 2.793-9.75 4.179-17.18 4.179-9.38 0-16.1-1.308-20.16-3.925-2.71-1.856-4.06-4.266-4.06-7.227 0-2.539 1.19-4.687 3.55-6.465 3.21-2.363 14.31-5.703 33.28-10.019 18.97-4.305 32.23-9.59 39.75-15.848 7.44-6.34 11.16-15.168 11.16-26.496 0-12.344-5.16-22.949-15.47-31.816-10.31-8.875-25.57-13.321-45.77-13.321-18.34 0-32.85 3.723-43.55 11.164-10.69 7.43-17.68 17.539-20.98 30.301"/><path d="m5993.03 324.68v-28.399h-24.34v-54.258c0-10.988.23-17.394.7-19.21.46-1.817 1.51-3.321 3.16-4.5 1.65-1.184 3.66-1.778 6.03-1.778 3.29 0 8.07 1.141 14.33 3.426l3.03-27.637c-8.28-3.554-17.66-5.332-28.14-5.332-6.42 0-12.21 1.086-17.37 3.235-5.15 2.156-8.93 4.949-11.34 8.367-2.42 3.429-4.09 8.058-5.01 13.886-.76 4.141-1.15 12.512-1.15 25.098v58.703h-16.35v28.399h16.35v26.758l35.76 20.789v-47.547z"/><path d="m6087.25 260.148c0-14.277 2.77-24.746 8.31-31.378 5.54-6.629 12.36-9.95 20.47-9.95 8.71 0 16.06 3.399 22.06 10.203 6.01 6.809 9 16.887 9 30.235 0 13.945-2.87 24.308-8.62 31.066-5.74 6.758-13.02 10.145-21.8 10.145-8.54 0-15.57-3.321-21.11-9.949-5.54-6.641-8.31-16.758-8.31-30.372zm-31.82-78.984 40.7-4.941c.67-4.739 2.23-7.989 4.7-9.766 3.37-2.531 8.7-3.801 15.96-3.801 9.3 0 16.27 1.399 20.92 4.18 3.13 1.867 5.5 4.863 7.1 9.004 1.1 2.961 1.65 8.41 1.65 16.359v19.649c-10.64-14.543-24.08-21.809-40.31-21.809-18.09 0-32.41 7.649-42.98 22.949-8.29 12.082-12.42 27.129-12.42 45.137 0 22.559 5.43 39.805 16.29 51.719 10.86 11.926 24.35 17.883 40.5 17.883 16.65 0 30.38-7.317 41.21-21.934v18.887h33.33v-120.821c0-15.89-1.3-27.765-3.92-35.625-2.62-7.863-6.3-14.035-11.04-18.507-4.72-4.481-11.04-7.989-18.94-10.528-7.91-2.539-17.9-3.797-29.99-3.797-22.82 0-39.01 3.907-48.56 11.719-9.55 7.82-14.32 17.734-14.32 29.734 0 1.184.04 2.618.12 4.309"/><path d="m6286.94 268.898c-.26 10.313-2.91 18.153-7.99 23.516-5.07 5.371-11.24 8.055-18.51 8.055-7.77 0-14.19-2.832-19.26-8.496-5.08-5.664-7.57-13.36-7.48-23.075zm-2.02-36.007 35.5-5.957c-4.58-13.016-11.78-22.93-21.63-29.727-9.84-6.805-22.16-10.215-36.95-10.215-23.42 0-40.74 7.656-51.98 22.949-8.88 12.258-13.31 27.727-13.31 46.407 0 22.316 5.83 39.785 17.49 52.422 11.67 12.636 26.41 18.957 44.25 18.957 20.04 0 35.84-6.614 47.42-19.844 11.57-13.223 17.11-33.488 16.6-60.793h-89.25c.26-10.567 3.13-18.789 8.62-24.656 5.49-5.879 12.34-8.809 20.54-8.809 5.58 0 10.27 1.523 14.07 4.559 3.8 3.046 6.67 7.949 8.63 14.707"/><path d="m6340.96 190.039v185.859h35.63v-185.859z"/><path d="m6431.11 260.273c0-14.363 1.99-24.765 5.97-31.179 5.74-9.309 13.76-13.946 24.08-13.946 8.2 0 15.17 3.485 20.92 10.457 5.75 6.973 8.62 17.383 8.62 31.25 0 15.469-2.78 26.602-8.37 33.411-5.58 6.797-12.72 10.203-21.43 10.203-8.44 0-15.52-3.36-21.23-10.078-5.7-6.719-8.56-16.758-8.56-30.118zm95.09-70.234h-33.09v19.777c-5.5-7.687-11.98-13.418-19.46-17.179-7.48-3.758-15.02-5.645-22.63-5.645-15.47 0-28.72 6.242-39.75 18.703-11.03 12.469-16.54 29.864-16.54 52.176 0 22.813 5.36 40.168 16.1 52.043 10.73 11.875 24.29 17.813 40.7 17.813 15.04 0 28.05-6.262 39.04-18.762v66.933h35.63z"/></g><path d="m6777.89 203.086 1.77-.059c-.39-.418-.72-.593-.94-.593l-10.29-.071c-.23 0-.56.129-1.01.606 1.07.234 1.93 1.457 1.95 2.902.03 1.68-1.04 3.086-2.31 3.086.02.117.08.184.14.234.44.664.9.84 1.13.84l10.29.125c.3 0 .71-.125 1.2-.781.1-.105.13-.184.18-.234h-1.96c-1.36.05-2.45-1.348-2.48-2.977-.06-1.68 1.01-3.078 2.33-3.078zm-24.44 6.242c-1.3 0-2.41-1.348-2.41-3.027-.06-1.574.88-2.91 2.14-3.098-.06 0-.12-.058-.16-.058-.73-.411-1.19-.352-1.43-.223l-9.22 4.57c-.19.125-.43.301-.58.789 1.14-.488 2.63.188 3.42 1.574.79 1.407.55 3.153-.64 3.809l-.51.371c.09 0 .21.098.34.164.72.371 1.14.305 1.4.188l9.22-4.602c.11-.047.34-.222.45-.515zm-20.58 11.055c-1.17.644-2.83.047-3.67-1.406-.79-1.504-.52-3.196.64-3.868l1.38-.851c-.64-.223-1.06-.223-1.24-.125l-9.26 4.59c-.19.078-.49.371-.65 1.113h1.6c1.33 0 2.44 1.316 2.44 3.016 0 1.086-.49 2.101-1.22 2.589.64.301 1.06.301 1.27.176l9.19-4.59c.29-.117.53-.41.69-1.261.05-.059 0-.059.05-.059zm-24.72-.547h.3c-.42-.5-.78-.617-1-.617h-10.27c-.23 0-.66.176-1.09.722h3c1.33 0 2.39 1.399 2.39 3.02 0 1.707-1.06 3.086-2.39 3.086h-3.16s0 .058.08.058c.47.672.94.86 1.17.86h10.27c.31 0 .7-.188 1.24-.86.04-.058.06-.187.08-.234h-.62c-1.36 0-2.41-1.34-2.41-3.019 0-1.7 1.05-3.016 2.41-3.016zm254.48 116.035c-1.26 2.402-3.34 4.317-6 5.34l-38.92 14.445-13.8 34.16c-.73 2.891-1.87 5.653-3.45 8.192-.49.898-1.06 1.691-1.66 2.402-.11.059-.14.156-.22.246-.05.059-.05.086-.12.125-3.25 4.035-7.75 7.246-13.1 8.938-6.19 1.992-12.53 1.707-18.16-.461-.73-.059-1.4-.195-2.11-.449l-45.86-14.903c-2.32-.789-4.23-2.195-5.57-4.011-1.64-1.68-2.82-3.848-3.19-6.399l-6.75-47.715c-.94-6.336 3.5-12.195 9.82-13.047 6.31-.906 12.2 3.469 13.08 9.766l5.82 41.379 16.38 5.398-14.36-41.472c-3.06-9.59-1.85-19.473 4.29-26.543l-6.67-14.778-39.58-87.89c-.3.129-.61.234-.96.234l-6.37.129c-.3 1.199-.72 2.305-1.45 3.191-1.12 1.582-2.95 2.844-5.15 2.793l-10.25-.078c-2.18-.058-4-1.308-5.1-2.89-.58-.848-1.02-1.817-1.28-2.832h-1.49c-.03.05-.03.129-.03.187-.23 1.934-1.3 3.867-3.32 4.805l-9.14 4.59c-1.96.925-4.15.613-5.9-.274-.83-.488-1.67-1.164-2.45-1.945l-.92.547c.23 1.211.29 2.344.14 3.496-.3 1.875-1.38 3.808-3.32 4.766l-9.25 4.601c-1.93.965-4.11.664-5.76-.254-1.57-.832-2.82-2.168-3.8-3.789h-2.76c-.26 1.094-.75 2.168-1.34 3.027-1.14 1.563-2.94 2.821-5.15 2.821h-10.27c-2.17 0-3.98-1.258-5.14-2.821-.57-.859-1-1.816-1.32-2.851h-1.4c-.03 1.387-.92 2.664-2.32 3.035-1.71.527-3.48-.437-4-2.187l-2.07-7c-.51-1.692.48-3.516 2.21-3.997 1.72-.546 3.5.422 3.97 2.18l.55 1.863h3.13c.25-.964.68-1.863 1.25-2.656 1.16-1.621 2.97-2.84 5.14-2.84h10.27c2.21 0 4.01 1.219 5.15 2.84.49.735.88 1.574 1.19 2.551h1.46c0-.188 0-.441.03-.617.28-1.934 1.36-3.867 3.35-4.774l9.16-4.59c1.96-.957 4.14-.664 5.89.243.78.422 1.41.976 2.04 1.64l1.26-.73c-.2-1.028-.23-1.992-.04-2.969.29-1.926 1.35-3.848 3.31-4.836l9.22-4.59c1.93-.945 4.11-.644 5.78.305 1.67.859 3.07 2.285 4.04 4.168l2.74-.059c.3-.957.73-1.933 1.34-2.714 1.1-1.59 2.92-2.782 5.12-2.782l10.29.137c2.16 0 3.98 1.25 5.08 2.891.49.722.86 1.511 1.16 2.304l5.98-.129c-.24-5.671 2.91-11.179 8.45-13.718 7.21-3.262 15.68 0 18.96 7.207l40.52 89.941 19.86-25.566 7.18-60.403c.92-7.851 8.03-13.535 15.93-12.558 7.9.89 13.48 8.027 12.58 15.929l-7.32 61.629c-.2 1.934-.85 6.653-4.94 12.024l-23.81 31.133c.14.242.94 2.07 2.02 4.707 4.5 10.879 14.8 36.433 14.8 36.433l2.41-5.957c.62-1.601 1.62-2.918 2.79-4.043 1.17-1.297 2.66-2.39 4.38-3.008l17.55-6.492 21.1-7.863 4.53-1.68.76-.293c5.8-2.195 12.21.774 14.43 6.535v.039l.74 4.208c-.03 1.718-.56 3.437-1.29 4.933zm-60.01 75.594c11.73 0 21.27 9.551 21.27 21.308 0 11.758-9.54 21.321-21.27 21.321-11.82 0-21.34-9.563-21.34-21.321 0-11.757 9.52-21.308 21.34-21.308" fill="#161315"/><path d="m6683.41 189.191h-78.74v78.778h78.74z" fill="#de1d27"/><path d="m6659.25 242.051c-4.12 0-5.87 4.601-11.7 4.601-5.71 0-8.7-3.761-10.47-8.828h14.79c2.1 0 4.07-.109 4.07-2.715 0-2.597-1.79-2.961-4.07-2.961h-15.79c-.09-.585-.14-1.152-.14-1.757v-2.286h12.8c2.09 0 4.02-.125 4.02-2.722 0-2.59-1.79-2.961-4.02-2.961h-12.11c1.51-5.742 4.67-9.844 11.07-9.844 5.18 0 8.24 4.277 12.02 4.277 2.68 0 4.27-2.234 4.27-4.765 0-7-11.73-8.699-16.98-8.699-12.44 0-19.75 7-21.86 19.031h-1.68c-1.98 0-3.94.324-3.94 2.832 0 3.019 2.85 2.851 5.07 2.851v2.051c0 .664 0 1.34.04 1.992h-1.31c-2 0-3.87.313-3.87 2.786 0 3.425 3.61 2.89 5.95 2.89 2.6 11.297 10.22 18.426 22.08 18.426 5.1 0 16.59-2.117 16.59-8.816 0-2.774-1.9-5.383-4.83-5.383" fill="#fff"/></g>
            </svg>
        </div>
        <div class="sp-logo">' . $svg_spray_pay . '</div>
        <main class="modal__content">
          <ul>
            <li>' . $p1 . '</li>
			<li>' . $p2 . '</li>
			<li>' . $p3 . '</li>
			<li>' . $p4 . '</li>
			<li>' . $p5 . '</li>
			</ul>

			<p>' . $p6 . '</p>
        </main>
      </div>
    </div>
  </div>';
}

/**
 * Main template for spraypay widget. Take price/total (for cart/checkout) and output
 * the final text.
 *
 */
function spray_pay_widget_tmpl( $data, $shoudReturn = false ) {
	$uid          = uniqid();
	$mustache     = new Mustache_Engine( array( 'entity_flags' => ENT_QUOTES ) );
	$final_text   = $mustache->render(
		$data['display_as_text'],
		array( 'bedrag' => $data['bedrag_formatted'] )
	);
	$final_text   = wp_kses( $final_text, array(
		'em'     => array(),
		'strong' => array(),
	) );
	$kses_args    = array(
		'div'            => array(
			'class'                 => array(),
			'data-trigger'          => array(),
			'aria-hidden'           => array(),
			'id'                    => array(),
			'data-micromodal-close' => array(),
			'data-modal-id'         => array(),
			'tabindex'              => array(),
			'role'                  => array(),
			'aria-modal'            => array(),
			'aria-label'            => array(),
		),
		'button'         => array(
			'class'                 => array(),
			'data-trigger'          => array(),
			'aria-hidden'           => array(),
			'id'                    => array(),
			'data-micromodal-close' => array(),
			'tabindex'              => array(),
			'role'                  => array(),
			'aria-modal'            => array(),
			'aria-label'            => array(),
		),
		'header'         => array(
			'class' => array()
		),
		'span'           => array(
			'class' => array(),
		),
		'em'             => array(),
		'strong'         => array(),
		'svg'            => array(
			'data-name'   => true,
			'xmlns'       => true,
			'xmlns:xlink' => true,
			'viewbox'     => true,
			'height'      => true,
			'width'       => true
		),
		'defs'           => array(),
		'style'          => array(),
		'path'           => array(
			'class'        => true,
			'd'            => true,
			'fill'         => true,
			'stroke'       => true,
			'stroke-width' => true,
		),
		'g'              => array(
			'transform' => true
		),
		'rect'           => array(
			'class'  => true,
			'x'      => true,
			'y'      => true,
			'rx'     => true,
			'width'  => true,
			'height' => true
		),
		'i'              => array(
			'class' => array(),
		),
		'p'              => array(),
		'br'             => array(),
		'b'              => array(),
		'ul'             => array(),
		'li'             => array(),
		'main'           => array(
			'class' => array(),
			'id'    => array(),
		),
		'a'              => array(
			'href'   => array(),
			'target' => array(),
		),
		'lineargradient' => array(
			'id'            => true,
			'x1'            => true,
			'y1'            => true,
			'x2'            => true,
			'y2'            => true,
			'gradientunits' => true,
			'xlink:href'    => true
		),
		'stop'           => array(
			'offset'     => true,
			'stop-color' => true
		),
	);
	$special_text = esc_html__( 'Let op! Geld lenen kost geld.', 'spraypay' );
	$tmpl         = '';

	$svg_spray_pay = '<svg data-name="Laag 1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 103.27971 41.21303"><defs><style>.cls-1{fill:#00358e;}.cls-2{fill:#00a9ce;}.cls-3{fill:url(#Naamloos_verloop_9);}.cls-4{fill:url(#Naamloos_verloop_9-2);}.cls-5{fill:url(#Naamloos_verloop_9-3);}.cls-6{fill:url(#Naamloos_verloop_9-4);}.cls-7{fill:url(#Naamloos_verloop_9-5);}.cls-8{fill:url(#Naamloos_verloop_9-6);}.cls-9{fill:url(#Naamloos_verloop_9-7);}.cls-10{fill:url(#Naamloos_verloop_9-8);}.cls-11{fill:url(#Naamloos_verloop_9-9);}.cls-12{fill:url(#Naamloos_verloop_9-10);}.cls-13{fill:url(#Naamloos_verloop_9-11);}.cls-14{fill:url(#Naamloos_verloop_9-12);}</style><linearGradient id="Naamloos_verloop_9" x1="30.95407" y1="5.87323" x2="72.30002" y2="5.87323" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#00358e"/><stop offset="1" stop-color="#00a9ce"/></linearGradient><linearGradient id="Naamloos_verloop_9-2" x1="30.95407" y1="7.44545" x2="72.30002" y2="7.44545" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-3" x1="30.95407" y1="8.52974" x2="72.30002" y2="8.52974" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-4" x1="30.95407" y1="9.19838" x2="72.30002" y2="9.19838" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-5" x1="30.95407" y1="9.45139" x2="72.30002" y2="9.45139" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-6" x1="30.95407" y1="9.34296" x2="72.30002" y2="9.34296" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-7" x1="30.95407" y1="8.89117" x2="72.30002" y2="8.89117" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-8" x1="30.95407" y1="8.09602" x2="72.30002" y2="8.09602" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-9" x1="30.95407" y1="6.93945" x2="72.30002" y2="6.93945" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-10" x1="30.95407" y1="5.36723" x2="72.30002" y2="5.36723" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-11" x1="30.95407" y1="3.37937" x2="72.30002" y2="3.37937" xlink:href="#Naamloos_verloop_9"/><linearGradient id="Naamloos_verloop_9-12" x1="30.95407" y1="0.90357" x2="72.30002" y2="0.90357" xlink:href="#Naamloos_verloop_9"/></defs><path class="cls-1" d="M5.94449,32.14217a8.28764,8.28764,0,0,1-3.26779-.56065A4.69029,4.69029,0,0,1,.708,30.11422,3.40859,3.40859,0,0,1,0,28.18558a.39357.39357,0,0,1,.12735-.28513A.41345.41345,0,0,1,.4325,27.7723H2.913a.74717.74717,0,0,1,.42289.09932,1.06382,1.06382,0,0,1,.2659.25469,2.317,2.317,0,0,0,.44292.57187,2.08667,2.08667,0,0,0,.75768.44211,3.42078,3.42078,0,0,0,1.14212.16659,3.36422,3.36422,0,0,0,1.722-.354,1.08372,1.08372,0,0,0,.58067-.96432.92567.92567,0,0,0-.31477-.72884,2.9925,2.9925,0,0,0-1.014-.50138,17.74867,17.74867,0,0,0-1.85976-.46294,11.23133,11.23133,0,0,1-2.54935-.817A3.88619,3.88619,0,0,1,.90505,24.16012a3.87243,3.87243,0,0,1,.12815-4.18245A4.46645,4.46645,0,0,1,2.933,18.50076a7.2085,7.2085,0,0,1,2.893-.53182,7.34206,7.34206,0,0,1,2.39158.35561,5.43413,5.43413,0,0,1,1.742.9451,4.48093,4.48093,0,0,1,1.07325,1.24945,2.8463,2.8463,0,0,1,.38364,1.28789.43656.43656,0,0,1-.10812.28673.38.38,0,0,1-.30516.12655H8.40494a.84235.84235,0,0,1-.374-.07689.71915.71915,0,0,1-.27552-.2563,1.36129,1.36129,0,0,0-.61992-.75928A2.3916,2.3916,0,0,0,5.826,20.80423a2.53008,2.53008,0,0,0-1.348.30435,1.03145,1.03145,0,0,0-.48216.93548.99438.99438,0,0,0,.26511.6888,2.12867,2.12867,0,0,0,.88583.5126,15.27194,15.27194,0,0,0,1.70277.45172,12.94135,12.94135,0,0,1,2.89375.83617,3.71679,3.71679,0,0,1,1.62349,1.30071,3.94248,3.94248,0,0,1-.24589,4.29938A4.87016,4.87016,0,0,1,9.02486,31.62,8.39671,8.39671,0,0,1,5.94449,32.14217Z"/><path class="cls-1" d="M14.34943,31.94514a.46575.46575,0,0,1-.35481-.14737.48976.48976,0,0,1-.13776-.3444V18.65774a.47179.47179,0,0,1,.49257-.49017h5.51119a7.418,7.418,0,0,1,2.8441.49978,4.13719,4.13719,0,0,1,1.89019,1.50735,4.43379,4.43379,0,0,1,.67838,2.53894,4.30007,4.30007,0,0,1-.67838,2.4989,3.99425,3.99425,0,0,1-1.89019,1.45769,7.823,7.823,0,0,1-2.8441.47094H17.51791v4.3122a.47.47,0,0,1-.14738.3444.49709.49709,0,0,1-.36442.14737Zm3.11-7.51912h2.30267a1.98958,1.98958,0,0,0,1.34876-.4341,1.64609,1.64609,0,0,0,.50138-1.31673,1.88552,1.88552,0,0,0-.4325-1.26066,1.76305,1.76305,0,0,0-1.41764-.511H17.45944Z"/><path class="cls-1" d="M27.65526,31.94514a.46577.46577,0,0,1-.35482-.14737.48976.48976,0,0,1-.13776-.3444V18.65774a.4718.4718,0,0,1,.49258-.49017h5.3534a6.24555,6.24555,0,0,1,4.01586,1.16936,4.01586,4.01586,0,0,1,1.45688,3.31744,4.04526,4.04526,0,0,1-.66957,2.36274,4.19814,4.19814,0,0,1-1.77166,1.45609l2.69673,4.84241a.49.49,0,0,1,.05927.21625.44018.44018,0,0,1-.41328.41328H35.76466a.7257.7257,0,0,1-.551-.18742,1.48462,1.48462,0,0,1-.2563-.3444l-2.2434-4.32982H30.706v4.36987a.47.47,0,0,1-.14737.3444.49838.49838,0,0,1-.36442.14737ZM30.706,24.28826h2.26343a1.907,1.907,0,0,0,1.388-.45332,1.62758,1.62758,0,0,0,.46214-1.22062,1.74021,1.74021,0,0,0-.44291-1.23983,1.85188,1.85188,0,0,0-1.40723-.471H30.706Z"/><path class="cls-1" d="M39.97674,31.94514a.44018.44018,0,0,1-.41328-.41328.71474.71474,0,0,1,.02-.17781l4.62536-12.63544a.792.792,0,0,1,.24589-.38445.75333.75333,0,0,1,.5222-.16659h2.913a.75253.75253,0,0,1,.5214.16659.792.792,0,0,1,.24589.38445l4.60614,12.63544a.39491.39491,0,0,1-.0889.46294.41657.41657,0,0,1-.30436.12815h-2.4212a.60436.60436,0,0,1-.44292-.14737.73376.73376,0,0,1-.18741-.26591l-.76729-2.00713h-5.2557l-.74806,2.00713a.78119.78119,0,0,1-.177.26591.62967.62967,0,0,1-.47255.14737Zm4.62616-5.25569h3.661L46.433,21.493Z"/><path class="cls-1" d="M57.31764,31.94514a.50362.50362,0,0,1-.49177-.49177V27.22126L52.259,18.7955c-.01281-.03845-.02643-.07369-.03924-.10733a.2967.2967,0,0,1-.01922-.10732.391.391,0,0,1,.12734-.28513.41347.41347,0,0,1,.30516-.12815h2.46045a.67238.67238,0,0,1,.46294.14737.925.925,0,0,1,.22586.26591l2.81526,5.07788L61.432,18.58085a.92479.92479,0,0,1,.22586-.26591.671.671,0,0,1,.46293-.14737h2.46046a.38317.38317,0,0,1,.29554.12815.40611.40611,0,0,1,.11774.28513.56883.56883,0,0,1-.00962.10732.99791.99791,0,0,1-.02963.10733L60.3884,27.22126v4.23211a.47.47,0,0,1-.14737.3444.49842.49842,0,0,1-.36443.14737Z"/><path class="cls-2" d="M67.17947,31.94514a.46573.46573,0,0,1-.35481-.14737.48971.48971,0,0,1-.13776-.3444V18.65774a.47179.47179,0,0,1,.49257-.49017h5.51119a7.41786,7.41786,0,0,1,2.84409.49978,4.13709,4.13709,0,0,1,1.89019,1.50735,4.43372,4.43372,0,0,1,.67839,2.53894,4.3,4.3,0,0,1-.67839,2.4989,3.99416,3.99416,0,0,1-1.89019,1.45769,7.82294,7.82294,0,0,1-2.84409.47094H70.34794v4.3122a.47.47,0,0,1-.14737.3444.49709.49709,0,0,1-.36442.14737Zm3.11-7.51912h2.30267a1.98959,1.98959,0,0,0,1.34877-.4341,1.64613,1.64613,0,0,0,.50138-1.31673,1.88552,1.88552,0,0,0-.4325-1.26066,1.76308,1.76308,0,0,0-1.41765-.511H70.28947Z"/><path class="cls-2" d="M78.26111,31.94514a.44018.44018,0,0,1-.41328-.41328.71425.71425,0,0,1,.02-.17781l4.62536-12.63544a.792.792,0,0,1,.24588-.38445.75337.75337,0,0,1,.52221-.16659h2.913a.75254.75254,0,0,1,.5214.16659.792.792,0,0,1,.24588.38445l4.60614,12.63544a.39486.39486,0,0,1-.0889.46294.41656.41656,0,0,1-.30435.12815H88.73325a.60432.60432,0,0,1-.44291-.14737.73368.73368,0,0,1-.18742-.26591l-.76729-2.00713H82.07994l-.74807,2.00713a.78129.78129,0,0,1-.177.26591.62967.62967,0,0,1-.47255.14737Zm4.62617-5.25569h3.661L84.7174,21.493Z"/><path class="cls-2" d="M95.60281,31.94514a.50364.50364,0,0,1-.49177-.49177V27.22126L90.54415,18.7955c-.01281-.03845-.02643-.07369-.03924-.10733a.29671.29671,0,0,1-.01923-.10732.39092.39092,0,0,1,.12735-.28513.41346.41346,0,0,1,.30515-.12815h2.46046a.67237.67237,0,0,1,.46293.14737.92479.92479,0,0,1,.22586.26591l2.81527,5.07788,2.83448-5.07788a.925.925,0,0,1,.22587-.26591.671.671,0,0,1,.46293-.14737h2.46045a.38319.38319,0,0,1,.29555.12815.4061.4061,0,0,1,.11773.28513.56886.56886,0,0,1-.00961.10732,1.00258,1.00258,0,0,1-.02963.10733l-4.5669,8.42576v4.23211a.47.47,0,0,1-.14737.3444.49838.49838,0,0,1-.36442.14737Z"/><path class="cls-1" d="M20.9822,41.213a1.91814,1.91814,0,0,1-.9669-.22438,1.479,1.479,0,0,1-.59583-.626,2.19732,2.19732,0,0,1-.224-.923q-.00653-.30172-.00653-.63612t.00653-.63541a2.1929,2.1929,0,0,1,.224-.92732,1.48151,1.48151,0,0,1,.59909-.62234,1.92331,1.92331,0,0,1,.96364-.22438,2.04189,2.04189,0,0,1,.78971.13724,1.68111,1.68111,0,0,1,.53556.34131,1.52833,1.52833,0,0,1,.3079.41174.95183.95183,0,0,1,.10711.34783.10822.10822,0,0,1-.03377.09731.151.151,0,0,1-.10675.037h-.14741a.11035.11035,0,0,1-.08714-.0305.327.327,0,0,1-.05338-.10385,1.21215,1.21215,0,0,0-.22438-.39794,1.187,1.187,0,0,0-.42155-.31443,1.565,1.565,0,0,0-.6659-.12418,1.41558,1.41558,0,0,0-.9669.3246,1.44283,1.44283,0,0,0-.39831,1.08128q-.02016.60235,0,1.20472a1.44391,1.44391,0,0,0,.39831,1.07692,1.40688,1.40688,0,0,0,.9669.32823,1.62574,1.62574,0,0,0,.70947-.15032,1.12989,1.12989,0,0,0,.49525-.46185,1.5629,1.5629,0,0,0,.18082-.793V39.065H21.20332a.13824.13824,0,0,1-.10711-.04357.15662.15662,0,0,1-.04031-.11038v-.09368a.15381.15381,0,0,1,.04031-.114.14378.14378,0,0,1,.10711-.03994h1.432a.13974.13974,0,0,1,.15394.154v.58893a2.02864,2.02864,0,0,1-.211.9433,1.51082,1.51082,0,0,1-.61543.63613A1.97337,1.97337,0,0,1,20.9822,41.213Z"/><path class="cls-1" d="M24.30154,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h2.61024a.13974.13974,0,0,1,.15395.154v.10021a.14429.14429,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067H24.576v1.70651h2.18833a.13975.13975,0,0,1,.154.15395v.10021a.14431.14431,0,0,1-.04031.10675.1531.1531,0,0,1-.11364.04066H24.576v1.77332h2.38911a.13974.13974,0,0,1,.15395.154v.10021a.14316.14316,0,0,1-.0403.10675.15308.15308,0,0,1-.11365.04067Z"/><path class="cls-1" d="M29.85606,41.213a2.18847,2.18847,0,0,1-.92007-.17428,1.43846,1.43846,0,0,1-.57876-.44805,1.04684,1.04684,0,0,1-.21422-.58239.12952.12952,0,0,1,.03994-.09368.136.136,0,0,1,.10058-.03994h.13361a.13356.13356,0,0,1,.10384.03994.165.165,0,0,1,.04357.09368.80166.80166,0,0,0,.16739.3718,1.04657,1.04657,0,0,0,.415.30717,1.72939,1.72939,0,0,0,.70911.12418,1.54794,1.54794,0,0,0,.9571-.23746.77225.77225,0,0,0,.30136-.639.59865.59865,0,0,0-.15758-.43208,1.38386,1.38386,0,0,0-.47819-.2941q-.32133-.13071-.82348-.2912a4.85906,4.85906,0,0,1-.78282-.31806,1.011,1.011,0,0,1-.59582-1.00067,1.07868,1.07868,0,0,1,.18081-.61216,1.23851,1.23851,0,0,1,.52539-.43135,1.97319,1.97319,0,0,1,.83982-.16121,2.02212,2.02212,0,0,1,.68951.10747,1.44229,1.44229,0,0,1,.48835.28466,1.27856,1.27856,0,0,1,.29446.38124.96962.96962,0,0,1,.10711.398.14857.14857,0,0,1-.0334.09077.12687.12687,0,0,1-.10711.04357h-.134a.194.194,0,0,1-.08351-.02687.138.138,0,0,1-.06354-.10747.77019.77019,0,0,0-.35147-.5519,1.37616,1.37616,0,0,0-.80642-.21785,1.51573,1.51573,0,0,0-.80968.19462.7494.7494,0,0,0-.17392,1.04714,1.15715,1.15715,0,0,0,.44151.30136q.30118.12963.77628.28394a6.24636,6.24636,0,0,1,.83.32169,1.23989,1.23989,0,0,1,.48836.39141,1.02727,1.02727,0,0,1,.16084.5991,1.16146,1.16146,0,0,1-.204.69277,1.28148,1.28148,0,0,1-.57913.435A2.406,2.406,0,0,1,29.85606,41.213Z"/><path class="cls-1" d="M32.98151,41.14623a.14481.14481,0,0,1-.10711-.04067.143.143,0,0,1-.03994-.10675V36.61562a.15369.15369,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h1.62627a1.95,1.95,0,0,1,.81332.15685,1.201,1.201,0,0,1,.53519.46548,1.62175,1.62175,0,0,1,0,1.5257,1.19508,1.19508,0,0,1-.53519.46475,1.93833,1.93833,0,0,1-.81332.15758H33.256v1.76678a.14319.14319,0,0,1-.0403.10675.15309.15309,0,0,1-.11365.04067Zm.2745-2.31578h1.31837a1.271,1.271,0,0,0,.86669-.25416,1.07793,1.07793,0,0,0,0-1.45888,1.26727,1.26727,0,0,0-.86669-.25416H33.256Z"/><path class="cls-1" d="M37.519,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h1.55946a1.7438,1.7438,0,0,1,1.12085.334,1.22494,1.22494,0,0,1,.41828,1.01737A1.29636,1.29636,0,0,1,40.35,38.67a1.34165,1.34165,0,0,1-.74287.435l1.07728,1.83359a.16773.16773,0,0,1,.02033.07334.12615.12615,0,0,1-.0403.09368.12888.12888,0,0,1-.09368.04067h-.08024a.20782.20782,0,0,1-.16049-.05737.69982.69982,0,0,1-.09367-.12345l-1.06421-1.80019H37.79351v1.83359a.14316.14316,0,0,1-.0403.10675.15308.15308,0,0,1-.11365.04067Zm.27449-2.38258h1.25157a1.33193,1.33193,0,0,0,.86669-.23746,1.03561,1.03561,0,0,0,0-1.42549,1.33193,1.33193,0,0,0-.86669-.23745H37.79351Z"/><path class="cls-1" d="M42.13677,41.14623a.1448.1448,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14434.14434,0,0,1,.10711-.03994H44.747a.13974.13974,0,0,1,.154.154v.10021a.14429.14429,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067H42.41126v1.70651h2.18833a.13974.13974,0,0,1,.154.15395v.10021a.14435.14435,0,0,1-.0403.10675.15313.15313,0,0,1-.11365.04066H42.41126v1.77332h2.38912a.13975.13975,0,0,1,.154.154v.10021a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><path class="cls-1" d="M46.43318,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.60836a.13753.13753,0,0,1,.14705-.14669h.12708a.13807.13807,0,0,1,.14742.14669v4.39045a.13914.13914,0,0,1-.14742.14742Z"/><path class="cls-1" d="M48.44759,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h1.42548a2.4578,2.4578,0,0,1,1.111.207,1.19824,1.19824,0,0,1,.57223.61289,2.61587,2.61587,0,0,1,.17718.98687c.00436.20043.0069.37834.0069.53229s-.00254.33114-.0069.53156a2.83,2.83,0,0,1-.18045,1.01737,1.1425,1.1425,0,0,1-.56242.5991,2.45963,2.45963,0,0,1-1.08418.19752Zm.27449-.40158h1.151a2.05382,2.05382,0,0,0,.84672-.14378.87282.87282,0,0,0,.44842-.46185,2.2298,2.2298,0,0,0,.14378-.84018c.00436-.13362.00653-.25053.00653-.35147v-.29773c0-.098-.00217-.21423-.00653-.34784a1.59719,1.59719,0,0,0-.3413-1.08781,1.50325,1.50325,0,0,0-1.131-.35074H48.72208Z"/><path class="cls-1" d="M55.37421,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994H57.121a1.55017,1.55017,0,0,1,.76611.167,1.065,1.065,0,0,1,.43861.43861,1.26375,1.26375,0,0,1,.14051.59183,1.21423,1.21423,0,0,1-.0904.49235.99559.99559,0,0,1-.22766.33114,1.17293,1.17293,0,0,1-.27086.19388,1.3033,1.3033,0,0,1,.47492.42845,1.21089,1.21089,0,0,1,.20768.716,1.37668,1.37668,0,0,1-.15722.639,1.24356,1.24356,0,0,1-.46874.49525,1.44122,1.44122,0,0,1-.76612.191Zm.2745-2.65054h1.38517a1.127,1.127,0,0,0,.753-.22076.76726.76726,0,0,0,.25743-.6158.70857.70857,0,0,0-.25743-.59546,1.20894,1.20894,0,0,0-.753-.20042H55.64871Zm0,2.249h1.45235a1.05891,1.05891,0,0,0,.76611-.26142.9486.9486,0,0,0,0-1.32818,1.07021,1.07021,0,0,0-.76611-.25779H55.64871Z"/><path class="cls-1" d="M60.0791,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h2.61024a.13975.13975,0,0,1,.154.154v.10021a.1443.1443,0,0,1-.04031.10675.15365.15365,0,0,1-.11364.04067H60.35359v1.70651h2.18833a.13974.13974,0,0,1,.154.15395v.10021a.14431.14431,0,0,1-.0403.10675.15313.15313,0,0,1-.11365.04066H60.35359v1.77332h2.38912a.13974.13974,0,0,1,.15395.154v.10021a.14319.14319,0,0,1-.0403.10675.15309.15309,0,0,1-.11365.04067Z"/><path class="cls-1" d="M65.39942,41.14623a.13859.13859,0,0,1-.14705-.14742V36.86325H63.9271a.13859.13859,0,0,1-.14705-.14742v-.10021a.15515.15515,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h3.06519a.13975.13975,0,0,1,.154.154v.10021a.1443.1443,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067H65.67392v4.13556a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><path class="cls-1" d="M67.45413,41.14623a.12886.12886,0,0,1-.09367-.04067.12616.12616,0,0,1-.04031-.09368.23173.23173,0,0,1,.01344-.07334L69.027,36.59529a.22548.22548,0,0,1,.07007-.10022.19861.19861,0,0,1,.12382-.0334h.22765a.19861.19861,0,0,1,.12382.0334.22833.22833,0,0,1,.07007.10022l1.69344,4.34325a.24091.24091,0,0,1,.01307.07334.1258.1258,0,0,1-.03994.09368.12884.12884,0,0,1-.09367.04067h-.134a.1278.1278,0,0,1-.10021-.037.30041.30041,0,0,1-.04684-.06318l-.415-1.0711H68.15017l-.415,1.0711a.15349.15349,0,0,1-.04357.06318.13931.13931,0,0,1-.10348.037Zm.85653-1.5729h2.04781l-1.02391-2.63674Z"/><path class="cls-1" d="M72.62051,41.14623a.1448.1448,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.60836a.13753.13753,0,0,1,.147-.14669h.12708a.13805.13805,0,0,1,.14741.14669v4.13629h2.30887a.13974.13974,0,0,1,.154.154v.10021a.14316.14316,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067Z"/><path class="cls-1" d="M76.62246,41.14623a.1448.1448,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14434.14434,0,0,1,.10711-.03994h2.61023a.13974.13974,0,0,1,.15395.154v.10021a.14429.14429,0,0,1-.0403.10675.15365.15365,0,0,1-.11365.04067H76.897v1.70651h2.18833a.13974.13974,0,0,1,.154.15395v.10021a.14435.14435,0,0,1-.0403.10675.15313.15313,0,0,1-.11365.04066H76.897v1.77332h2.38912a.13975.13975,0,0,1,.154.154v.10021a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><path class="cls-1" d="M80.91887,41.14623a.14481.14481,0,0,1-.10711-.04067.14294.14294,0,0,1-.03994-.10675V36.61562a.15365.15365,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h.14052a.1362.1362,0,0,1,.10057.0334.23558.23558,0,0,1,.03994.04648l2.46972,3.77466V36.61562a.15515.15515,0,0,1,.03994-.114.14435.14435,0,0,1,.10711-.03994h.12055a.13926.13926,0,0,1,.15358.154v4.37666a.15638.15638,0,0,1-.03994.11038.13877.13877,0,0,1-.10711.04357h-.147a.12613.12613,0,0,1-.09694-.03341c-.02033-.02251-.03486-.03776-.04357-.0472l-2.46282-3.76086v3.694a.14316.14316,0,0,1-.04031.10675.15307.15307,0,0,1-.11364.04067Z"/><rect class="cls-3" x="30.85765" width="1.80715" height="11.74646" rx="0.90357"/><rect class="cls-4" x="34.47195" y="2.02401" width="1.80715" height="10.84289" rx="0.90357"/><rect class="cls-5" x="38.08624" y="3.56008" width="1.80715" height="9.93932" rx="0.90357"/><rect class="cls-6" x="41.70054" y="4.68051" width="1.80715" height="9.03574" rx="0.90357"/><rect class="cls-7" x="45.31484" y="5.3853" width="1.80715" height="8.13217" rx="0.90357"/><rect class="cls-8" x="48.92913" y="5.72866" width="1.80715" height="7.22859" rx="0.90357"/><rect class="cls-9" x="52.54343" y="5.72866" width="1.80715" height="6.32502" rx="0.90357"/><rect class="cls-10" x="56.15773" y="5.3853" width="1.80715" height="5.42144" rx="0.90357"/><rect class="cls-11" x="59.77202" y="4.68051" width="1.80715" height="4.51787" rx="0.90357"/><rect class="cls-12" x="63.38632" y="3.56008" width="1.80715" height="3.6143" rx="0.90357"/><rect class="cls-13" x="67.00062" y="2.02401" width="1.80715" height="2.71072" rx="0.90357"/><rect class="cls-14" x="70.61491" width="1.80715" height="1.80715" rx="0.90357"/></svg>';

	switch ( $data['appearance'] ) :
		case 'branded' :
			$tmpl .= '<div class="sprayPayWidget noBg withLogo" data-modal-id="sprayPayModal_' . esc_attr( $uid ) . '" data-trigger="sprayPayModal">
<i class="logo">' . $svg_spray_pay . '</i>
<p>' . $final_text . '<br><b>' . $special_text . '</b></p><i class="info">i</i></div>';
			break;
		case 'label' :
			$tmpl .= '<div class="sprayPayWidget noBg" data-modal-id="sprayPayModal_' . esc_attr( $uid ) . '" data-trigger="sprayPayModal">
<p>' . $final_text . '<br><b>' . $special_text . '</b></p><i class="info">i</i></div>';
			break;
	endswitch;

	$tmpl .= '<br>';

	$tmpl .= spray_pay_modal_html( $data, $svg_spray_pay, $uid );

	// end display description
	if ( $shoudReturn ) {
		return $tmpl;
	} else {
		echo wp_kses( $tmpl, $kses_args );
	}
}

/**
 * Check whether widget must be displayed in the cart
 *
 */
function spray_pay_display_in_cart() {
	$spray_pay_settings = get_option( 'spray_pay_settings' );
	$price              = WC()->cart->get_total( 'edit' );
	$should_display     = spray_pay_should_display( $price, $spray_pay_settings );

	if ( ! $should_display ) {
		return;
	}

	$bedrag_formatted = spray_pay_formatted( $price );

	$data = [
		'appearance'       => $spray_pay_settings['appearance'],
		'display_as_text'  => SprayPay()->widget_get_display_text_tmpl( $spray_pay_settings ),
		'bedrag_formatted' => spraypay_format_price( $bedrag_formatted ),
		'popup_content'    => ''
	];

	echo '<tr class="sprayPayWidget__row"><td colspan="2">';
	spray_pay_widget_tmpl( $data );
	echo '</td></tr>';
}